Oneshot

Type Alias Oneshot 

pub type Oneshot = Oneshot<OwnedReadHalf, OwnedWriteHalf>;
Invoke and Accept implementation in terms of a single UnixStream.

Either Invoke::invoke or Accept::accept can only be called at most once on Oneshot, repeated calls with return an error

Aliased Type

pub struct Oneshot(/* private fields */);

Implementations

Source

impl Oneshot

pub fn unix_pair() -> Result<(Oneshot, Oneshot)>

Creates a pair of connected Oneshot using UnixStream::pair.